//gameplay functions

var playBack = 240;
var players, wins = [0, 0];
var gameOver;

//setup for play
function playSetup(){
    background(playBack);

    //reset players and gameover
    players = [];
    gameOver = false;

    //play area bounds
    stroke(0);
    strokeWeight(8);
    line(0, 0, 0, height);
    line(0, 0, width, 0);
    line(0, height, width, height);
    line(width, 0, width, width);

    //make player 1
    append(players, makeTurtle(width/4, height/2+25));
    players[0].setColor('blue');
    players[0].setWeight(3);
    //print(players[0].weight);
    players[0].face(270);
    players[0].xDir = 0;
    players[0].yDir = -1;

    //make player 2
    append(players, makeTurtle(3*width/4, height/2+25));
    players[1].setColor('red');
    players[1].setWeight(3);
    //print(players[1].weight);
    players[1].face(90);
    players[1].xDir = 0;
    players[1].yDir = 1;

    //display score
    displayScore();
}

//draw function for play
function playDraw(){
    //only draw if game is not over
    if (!gameOver){
        if (frameCount%fps === 0)
            displayScore();

        //move players
        for (var i = 0; i < players.length; i++)
            playerMove(players[i]);

        //check for powerup and remove before collision takes place

        //check if collision occurs
        for (var i = 0; i < players.length; i++)
            playCollide(players[i]);
        
        //check for winner, show if game 
        showWinner()
    }
}

//displays the winner of the round, each player's wins, and instructions
function showWinner(){
    //check if all players have stopped moving, if not ret false
    for (var i = 0; i < players.length; i++){
        if (players[i].speed != 0)
            return false;
    }

    //check lengths and determine winner
    var long = 0;
    for (var i = 0; i < players.length; i++){
        if (players[i].len > players[long].len){
            long = i;
        }
        else if (players[i].len === players[long].len){
            //long = 101;
        }
    }

    //setup text for winner display
    fill(0);
    stroke(players[long].color);
    strokeWeight(2);
    textSize(48);
    textAlign(CENTER, CENTER);

    //check for draw
    if (long === 101)
        text("DRAW!!", width/2, height/2);
    //otherwise show winner
    else
        text("Player " + (long+1) + " wins!!", width/2, height/3);

    //show commands post game
    textSize(24)
    text("Press ENTER to play again!\nPress SHIFT to return to start!", 
        width/2, 2*height/3);

    //game is over
    gameOver = true;

    //increment and display player wins
    wins[long] ++;
    text('Player 1 has ' + wins[0] + " wins!\nPlayer 2 has " +
        wins[1] + ' wins!', width/2, height/2)
}

//displays score at the top of the screen
function displayScore(){
    //clear top of background
    fill(playBack);
    stroke(0);
    strokeWeight(4);
    rect(0, 0, width, 50);

    //display score
    fill(0);
    noStroke();
    textAlign(LEFT, TOP);
    text("Player 1: " + int(players[0].len), 10, 10);
    text('Player 2: ' + int(players[1].len), 2*width/3, 10);
}

//checks to see if the received player has collided with anything
function playCollide(player){
    if (player.speed !== 0){
        //get color of pixel in front of player
        var x = int(player.x+player.xDir*player.weight);
        var y = int(player.y+player.yDir*player.weight);
        var col = get(x, y);
        var backCol = [playBack, playBack, playBack, 255];

        //stop moving if player hits another or self
        if (!colorArrEqual(col, backCol)){
            player.speed = 0;
        }
    }
}

//checks if the arrays sent in represent the same color
function colorArrEqual(a1, a2){
    for (var i = 0; i<a1.length; i++){
        if (a1[i] !== a2[i])
            return false;
    }
    return true;
}

//moves the player sent in
function playerMove(player){
    //print(players[0].move);
    player.forward(player.speed);
    player.len += player.speed;

    //slowly increase player speed (0.05% per frame)
    player.speed *= 1.0005;
}

//keypressed function for play mode
function playKeyPressed(){
    //move players[0]
    if (key === 'w'){
        if (players[0].yDir != 1){
            //print(players[0].angle);
            players[0].face(270);
            players[0].xDir = 0;
            players[0].yDir = -1;
        }
    }
    if (key === 'a'){
        if (players[0].xDir != 1){
            players[0].face(180);
            players[0].xDir = -1;
            players[0].yDir = 0;
        }
    }
    if (key === 's'){
        if (players[0].yDir != -1){
            players[0].face(90);
            players[0].xDir = 0;
            players[0].yDir = 1;
        }
    }
    if (key === 'd'){
        if (players[0].xDir != -1){
            players[0].face(0);
            players[0].xDir = 1;
            players[0].yDir = 0;
        }
    }

    //move players[1]
    if (keyCode === 38){
        if (players[1].yDir != 1){
            players[1].face(270);
            players[1].xDir = 0;
            players[1].yDir = -1;
        }
    }
    if (keyCode === 37){
        if (players[1].xDir != 1){
            players[1].face(180);
            players[1].xDir = -1;
            players[1].yDir = 0;
        }
    }
    if (keyCode === 40){
        if (players[1].yDir != -1){
            players[1].face(90);
            players[1].xDir = 0;
            players[1].yDir = 1;
        }
    }
    if (keyCode === 39){
        if (players[1].xDir != -1){
            players[1].face(0);
            players[1].xDir = 1;
            players[1].yDir = 0;
        }
    }

    //restart game
    if (keyCode === ENTER && gameOver)
        playSetup();

    //return to start
    else if(keyCode === SHIFT && gameOver){
        gameState = 'start';
        startSetup();
    }
}